ScrellaApiBaseResponse<T> class

Constructors

ScrellaApiBaseResponse({required bool status, required String message, required T? data})
ScrellaApiBaseResponse.fromJson(Map<String, dynamic>? json, T deserialize(dynamic data))
Creates a ScrellaApiBaseResponse from a decoded JSON map.
factory
ScrellaApiBaseResponse.fromJson2(Map<String, dynamic>? json)
Creates a ScrellaApiBaseResponse from a decoded JSON map.
factory

Properties

data → T?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited