ClaimData class
Constructors
- ClaimData({required int id, required String claimIdentifier, required int status, required String statusText, required String statusMessage, required String timeCreated, required int issue, required String issueText, required String description, required String vendorUser, required String vendorBusiness, required String vendorBusinessAddress, required String duration, required bool hasIssue, required bool canReportIssue, required int enterpirseId, required String enterpriseName, required String enterpriseUser, required String device})
-
ClaimData.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- canReportIssue → bool
-
final
- claimIdentifier → String
-
final
- description → String
-
final
- device → String
-
final
- duration → String
-
final
- enterpirseId → int
-
final
- enterpriseName → String
-
final
- enterpriseUser → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIssue → bool
-
final
- id → int
-
final
- issue → int
-
final
- issueText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
final
- statusMessage → String
-
final
- statusText → String
-
final
- timeCreated → String
-
final
- vendorBusiness → String
-
final
- vendorBusinessAddress → String
-
final
- vendorUser → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited