ConfirmOtpPayload class

Constructors

ConfirmOtpPayload({required int requestId, required String otp, required DeviceTypeEnum deviceType, required String pushNotificationToken})
ConfirmOtpPayload.defaults()
factory

Properties

deviceType DeviceTypeEnum
final
hashCode int
The hash code for this object.
no setterinherited
otp String
final
pushNotificationToken String
final
requestId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? requestId, String? otp, DeviceTypeEnum? deviceType, String? pushNotificationToken}) ConfirmOtpPayload
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited