DeviceInfoData class

Constructors

DeviceInfoData({required int id, required List<String> imei, required String deviceModel, required String modelNo, required int? deviceHealthStatus, required double? healthRating, required int status, required int? deviceHealthCheckStatus, required int onboardingStatus, required bool canReceiveFPLNotifications, required String timeCreated, required String timeUpdated})
DeviceInfoData.fromJson(Map<String, dynamic>? json)
factory

Properties

canReceiveFPLNotifications bool
final
deviceHealthCheckStatus int?
final
deviceHealthStatus int?
final
deviceModel String
final
hashCode int
The hash code for this object.
no setterinherited
healthRating double?
final
id int
final
imei List<String>
final
modelNo String
final
onboardingStatus int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
timeCreated String
final
timeUpdated String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited