PlanData class
Constructors
-
PlanData({required int id, required String? iconDark, required String? iconLight, required String? backPhoto, required String? name, required String? primaryTagLine, required String? secondaryTagLine, required int? durationInMonths, required double? amount, required double? insuranceFee, required double? cover, required String? note, required int? type, required String? typeText, required int? status, required String? statusText, required int? waitingPeriodInDays, required List<
String> planOfferings, required List<String> planExclusions, required List<String> planBenefits, required String? timeCreated, required String? timeUpdated, required int? totalSubscribers, required int? activeSubscribers, required double? referralBonus}) -
PlanData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeSubscribers → int?
-
final
- amount → double?
-
final
- backPhoto → String?
-
final
- cover → double?
-
final
- durationInMonths → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconDark → String?
-
final
- iconLight → String?
-
final
- id → int
-
final
- insuranceFee → double?
-
final
- name → String?
-
final
- note → String?
-
final
-
planBenefits
→ List<
String> -
final
-
planExclusions
→ List<
String> -
final
-
planOfferings
→ List<
String> -
final
- primaryTagLine → String?
-
final
- referralBonus → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryTagLine → String?
-
final
- status → int?
-
final
- statusText → String?
-
final
- timeCreated → String?
-
final
- timeUpdated → String?
-
final
- totalSubscribers → int?
-
final
- type → int?
-
final
- typeText → String?
-
final
- waitingPeriodInDays → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited