SubscriptionPlan class
Constructors
- SubscriptionPlan({required int id, required int planId, required String planName, required String startTime, required String startTimeFormatted, required String waitPeriodExpiryTime, required String expiryTime, required String expiryTimeFormatted, required String proofOfPayment, required String insuranceCertificate, required int status, required String iconDark, required String iconLight})
-
SubscriptionPlan.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- expiryTime → String
-
final
- expiryTimeFormatted → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconDark → String
-
final
- iconLight → String
-
final
- id → int
-
final
- insuranceCertificate → String
-
final
- planId → int
-
final
- planName → String
-
final
- proofOfPayment → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → String
-
final
- startTimeFormatted → String
-
final
- status → int
-
final
- waitPeriodExpiryTime → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited