TerminatePlanPayload class

Constructors

TerminatePlanPayload({required int reason, required String reasonText, required int userPlanId})

Properties

hashCode int
The hash code for this object.
no setterinherited
reason int
final
reasonText String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userPlanId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited