UserInfo class

Constructors

UserInfo({required int userId, required String userIdentifier, required String firstName, required String lastName, required String email, required String phoneNumber, required bool isKYCVerified, required String referralCode, required double referralBonusBalance, required double? walletBalance})
UserInfo.fromJson(Map<String, dynamic>? json)
factory

Properties

email String
final
firstName String
final
hashCode int
The hash code for this object.
no setterinherited
isKYCVerified bool
final
lastName String
final
phoneNumber String
final
referralBonusBalance double
final
referralCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
final
userIdentifier String
final
walletBalance double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited