FileUploadHelper class

Constructors

FileUploadHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(Uint8List bytes, {required String filename}) → MultipartFile
From raw bytes (snapshot buffers, etc.)
fromFile(File file) Future<MultipartFile>
From File
fromXFile(XFile file) Future<MultipartFile>
From XFile (camera / image picker)