ScrellaApiResponseData class abstract

All response data classes must implement a factory constructor: factory ClassName.fromJson(Map<String, dynamic> json)

Implementers

Constructors

ScrellaApiResponseData()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited