ScrellaApiClient class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearAuthToken(
) → Future< void> - Clear auth token (logout)
-
getClientInstance(
) → Dio - Access the initialized Dio instance
-
initialize(
{required String partnerApiKey}) → Future< void> - Initializes the API client's singleton with base URL, API keys and headers
-
setAuthToken(
String token) → Future< void> - Update the auth token dynamically (after login/OTP)
-
tokenExists(
) → Future< bool> - Check if token exists