DeviceIdentity class
Represents the device identity
Constructors
- DeviceIdentity({required String deviceId, String? platformId, String? model, String? modelId, String? osVersion, required String platform})
-
DeviceIdentity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deviceId → String
-
Platform-agnostic device ID
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
Device model (Pixel 7, iPhone14, etc.)
final
- modelId → String?
-
Device model ID (Pixel 7, iPhone14, etc.)
final
- osVersion → String?
-
OS version
final
- platform → String
-
Platform name ("android" / "ios")
final
- platformId → String?
-
Optional platform hint (Android ANDROID_ID / iOS IDFV)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited