InternalSignUpPayload class
Constructors
- InternalSignUpPayload({required SignUpPayload signUpPayload, required String? deviceModel, required String? deviceModelNo, required String? deviceId})
-
const
- InternalSignUpPayload.fromSignUpPayload({required SignUpPayload payload, required String deviceModel, required String deviceModelNo, required String deviceId})
-
🔁 Absorb an existing SignUpPayload
factory
Properties
- deviceId → String?
-
final
- deviceModel → String?
-
final
- deviceModelNo → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signUpPayload → SignUpPayload
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited