SignUpPayload class
Constructors
- SignUpPayload({required String firstName, required String lastName, required String emailAddress, required String phoneNumber, required bool isTermsConditionsAgreed, required String deviceModel, required String deviceModelNo, required String deviceId, required String pushNotificationToken})
- SignUpPayload.defaults()
-
factory
Properties
- deviceId → String
-
final
- deviceModel → String
-
final
- deviceModelNo → String
-
final
- emailAddress → String
-
final
- firstName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTermsConditionsAgreed → bool
-
final
- lastName → String
-
final
- phoneNumber → String
-
final
- pushNotificationToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? firstName, String? lastName, String? emailAddress, String? phoneNumber, bool? isTermsConditionsAgreed, String? deviceModel, String? deviceModelNo, String? deviceId, String? pushNotificationToken}) → SignUpPayload -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited