UserPlanPayload class
Constructors
- UserPlanPayload({required int planId, required double planAmount, required String nin})
- UserPlanPayload.defaultValues()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nin → String
-
final
- planAmount → double
-
final
- planId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? planId, double? planAmount, String? nin}) → UserPlanPayload -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited