UserStatusResponse class

Constructors

UserStatusResponse({required String imeiUrl, required UserInfo userInfo, required int onboardingStatus, required int deviceHealthCheckStatus, required DeviceHealthInfo deviceHealthInfo, required SubscriptionPlan? activePlan, required double walletBalance, required String? fplTeam, required DeviceInfoData deviceInfo})
UserStatusResponse.fromJson(dynamic json)
factory

Properties

activePlan SubscriptionPlan?
final
deviceHealthCheckStatus int
final
deviceHealthInfo DeviceHealthInfo
final
deviceInfo DeviceInfoData
final
fplTeam String?
final
hashCode int
The hash code for this object.
no setterinherited
imeiUrl String
final
onboardingStatus int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userInfo UserInfo
final
walletBalance double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited